==> ogre-13.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_deprecated_8h.js <==
var _ogre_deprecated_8h =
[
    [ "OGRE_HashMap", "group__deprecated.html#gaae66141905ddac9ea7b0a562d2dab69d", null ],
    [ "OGRE_HashMultiMap", "group__deprecated.html#ga669d1b4211776fa2d7fdbf0e17ecd304", null ],
    [ "OGRE_HashSet", "group__deprecated.html#gacff21880202e98896528710bed75fce4", null ],
    [ "OGRE_HashMultiSet", "group__deprecated.html#ga973d69768eae85a9282eb97ee0d3bced", null ],
    [ "AtomicScalar", "_ogre_deprecated_8h.html#gae1e422544f08b706423dbb83aa4c20d1", null ],
    [ "QuadMaterialMap", "_ogre_deprecated_8h.html#ga30d973e2d8b22c92d4b09f78c0531508", null ],
    [ "SceneTypeMask", "_ogre_deprecated_8h.html#gaa4b6dbd7bf722582a21fcc25d25f73ed", null ],
    [ "SceneType", "_ogre_deprecated_8h.html#ga7383602bd480d43b80c626969b9af914", [
      [ "ST_GENERIC", "_ogre_deprecated_8h.html#gga7383602bd480d43b80c626969b9af914a0af8f844019e52fe112e9a946a919fcd", null ],
      [ "ST_EXTERIOR_CLOSE", "_ogre_deprecated_8h.html#gga7383602bd480d43b80c626969b9af914ae83ae1c9a6e4816184441db4a140e70a", null ],
      [ "ST_EXTERIOR_FAR", "_ogre_deprecated_8h.html#gga7383602bd480d43b80c626969b9af914a8bf5864d5ab311e0512ed153c95f1d13", null ],
      [ "ST_EXTERIOR_REAL_FAR", "_ogre_deprecated_8h.html#gga7383602bd480d43b80c626969b9af914a7eecd7057b3487616075032560582ec1", null ],
      [ "ST_INTERIOR", "_ogre_deprecated_8h.html#gga7383602bd480d43b80c626969b9af914a93f2170ad3a8132f29264dc3642a2dcf", null ]
    ] ],
    [ "SPFM_NONE", "_ogre_deprecated_8h.html#ga7eed296b598179beccca6458853544f2", null ]
];

==> ogre-14.3.2-2-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_deprecated_8h.js <==
var _ogre_deprecated_8h =
[
    [ "OGRE_HashMap", "group__deprecated.html#gaae66141905ddac9ea7b0a562d2dab69d", null ],
    [ "OGRE_HashMultiMap", "group__deprecated.html#ga669d1b4211776fa2d7fdbf0e17ecd304", null ],
    [ "OGRE_HashSet", "group__deprecated.html#gacff21880202e98896528710bed75fce4", null ],
    [ "OGRE_HashMultiSet", "group__deprecated.html#ga973d69768eae85a9282eb97ee0d3bced", null ],
    [ "AtomicScalar", "_ogre_deprecated_8h.html#ga64d5737d0d756e87a82f40b70ce377f9", null ],
    [ "QuadMaterialMap", "_ogre_deprecated_8h.html#ga30d973e2d8b22c92d4b09f78c0531508", null ],
    [ "SceneTypeMask", "_ogre_deprecated_8h.html#gaa4b6dbd7bf722582a21fcc25d25f73ed", null ],
    [ "SceneType", "_ogre_deprecated_8h.html#ga7383602bd480d43b80c626969b9af914", [
      [ "ST_GENERIC", "_ogre_deprecated_8h.html#gga7383602bd480d43b80c626969b9af914a0af8f844019e52fe112e9a946a919fcd", null ],
      [ "ST_EXTERIOR_CLOSE", "_ogre_deprecated_8h.html#gga7383602bd480d43b80c626969b9af914ae83ae1c9a6e4816184441db4a140e70a", null ],
      [ "ST_EXTERIOR_FAR", "_ogre_deprecated_8h.html#gga7383602bd480d43b80c626969b9af914a8bf5864d5ab311e0512ed153c95f1d13", null ],
      [ "ST_EXTERIOR_REAL_FAR", "_ogre_deprecated_8h.html#gga7383602bd480d43b80c626969b9af914a7eecd7057b3487616075032560582ec1", null ],
      [ "ST_INTERIOR", "_ogre_deprecated_8h.html#gga7383602bd480d43b80c626969b9af914a93f2170ad3a8132f29264dc3642a2dcf", null ]
    ] ],
    [ "SPFM_NONE", "_ogre_deprecated_8h.html#ga7eed296b598179beccca6458853544f2", null ],
    [ "SPFM_DELETE_T", "_ogre_deprecated_8h.html#gaf6f97a6839d09383771cbe638a56f256", null ]
];
